#
# spec file for package python-ipysheet
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distversion 0.7
%define skip_python39 1
Name:           python-ipysheet
Version:        0.7.0
Release:        4.2
Summary:        Spreadsheet widget for the Jupyter notebook
License:        MIT
URL:            https://github.com/QuantStack/ipysheet
Source:         https://files.pythonhosted.org/packages/source/i/ipysheet/ipysheet-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module jupyter_packaging >= 0.7.9 with %python-jupyter_packaging < 1}
BuildRequires:  %{python_module jupyterlab >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 40.8}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  jupyter-rpm-macros
BuildRequires:  python-rpm-macros
Requires:       jupyter-ipysheet = %{version}
Requires:       (python-ipywidgets >= 7.5.0 with python-ipywidgets < 9)
Recommends:     python-pscript
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipywidgets >= 7.5.0 with %python-ipywidgets < 9}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pscript}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Jupyter widget providing spreadsheets for the Jupyter notebook.

WARNING
Due to Handsontable licensing changes ipysheet is stuck witch the
outdated Handsontable version 6.2.2 (open-source). We recommend
not using ipysheet anymore. We suggest an alternative like
ipydatagrid.

This package provides the python interface.

%package -n jupyter-ipysheet
Summary:        Spreadsheet widget for the Jupyter notebook - Jupyterfiles
Requires:       (jupyter-ipywidgets >= 7.5.0 with jupyter-ipywidgets < 9)
Requires:       (jupyter-jupyterlab or jupyter-notebook)
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(ipysheet) = %{distversion}
Suggests:       python3-ipysheet
Provides:       jupyter-ipysheet = %{version}-%{release}

%description -n jupyter-ipysheet
A Jupyter widget providing spreadsheets for the Jupyter notebook.

This package provides the extensions for jupyter notebook and jupyterlab.

%prep
%autosetup -p1 -n ipysheet-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/ipysheet/
%{python_sitelib}/ipysheet-%{version}.dist-info

%files -n jupyter-ipysheet
%license LICENSE
%{_jupyter_config} %{_jupyter_nb_notebook_confdir}/ipysheet.json
%{_jupyter_nbextension_dir}/ipysheet
%{_jupyter_labextensions_dir3}/ipysheet

%changelog
* Thu Mar  7 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19 (through
  ipywidgets)
* Thu Aug 17 2023 Ben Greiner <code@bnavigator.de>
- Suggest primary python package -- boo#1214354
* Tue Jun 13 2023 Ben Greiner <code@bnavigator.de>
- Unpin jupyterlab build requirement
* Sun Dec 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.7
  * no release note (removes jupyter-server dependency)
- Move to PEP517 build
* Thu Oct 13 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.6
  * no release notes
- Added compatibility with ipywidgets 8.x
- Added a warning about the deprecation of the whole package
* Wed Oct  5 2022 Ben Greiner <code@bnavigator.de>
- Revert 233.patch. Wait for working PR
  - - gh#quantstack/ipysheet#233
* Wed Oct  5 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add patch 233.patch to fix incompatibility with ipywidgets 8.x
  gh#quantstack/ipysheet#233
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.5
  * no release notes
* Mon Apr 26 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue Jun 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.4:
  * support for jupyterlab 2
* Sat Jul 27 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.3
  * Update to JupyterLab 1.0
  * Use Image.from_file instead of Image.from_url
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.4.2
  * Clear notebook state
  * Fixup Jupyterlab extension
  * Safe conditional formatting
  * Add time cell type
  * Fix row/column unused arguments
  * Fix security issue due to growl<0.10
* Tue Apr 30 2019 Todd R <toddrme2178@gmail.com>
- Initial version (0.3.4)
